@@ -1,8 +1,9 @@
-#!/usr/bin/env python
 # ~*~ coding: utf-8 ~*~
 
 # Copyright © 2017
 #       Dominik George <nik@naturalnet.de>
+# Copyright © 2021
+#       mirabilos <m@mirbsd.org>
 #
 # Provided that these terms and disclaimer and all copyright notices
 # are retained or reproduced in an accompanying document, permission
@@ -22,21 +23,23 @@
 import os
 import unittest
 
-from mmllib.parser import mml_file, mml_file_meta
+from .util import round_sequence_r, TestCase
 
-class ParserTests(unittest.TestCase):
+from mmllib.parser import mml_file, mml_file_meta
+from mmllib.mml import mml
+
+class ParserTests(TestCase):
     def setUp(self):
         self.datadir = os.path.join(os.path.dirname(__file__), "data")
-        self.examplesdir = os.path.abspath(os.path.join(self.datadir, "..", "..", "examples"))
 
     def test_mml_file_meta(self):
-        mmlfile = os.path.join(self.examplesdir, "loreley.mml")
+        mmlfile = os.path.join(self.datadir, "loreley.mml")
         res_meta = mml_file_meta(mmlfile)
         expected_meta = {'arranger': u'Klavier: August Linder; MML: mirabilos',
                          'composer': u'Ph. Friedrich Silcher (1789\u20131860), 1837',
                          'copyright': u'MML encoding & arrangement \xa9 2016 mirabilos, published under The MirOS Licence; copyright for text, music, and piano arrangement has expired',
                          'duration': 37.89473684210526,
-                         'encoder': u'mirabilos, 2016',
+                         'encoder': u'mirabilos, 2016, Python testsuite 2017',
                          'instruments': u'Piano, Voice',
                          'key signature': u'C Major',
                          'language': u'German',
@@ -53,10 +56,10 @@ class ParserTests(unittest.TestCase):
         self.assertDictEqual(res_meta, expected_meta)
 
     def test_mml_file(self):
-        mmlfile = os.path.join(self.examplesdir, "loreley.mml")
+        mmlfile = os.path.join(self.datadir, "loreley.mml")
         res = mml_file(mmlfile)
-        expected = [[(391.99543598174927, 0.34539473684210525),
-                     (0, 0.04934210526315791),
+        expected = [[(391.99543598174927, 0.29605263157894735),
+                     (0, 0.098684210526315819),
                      1,
                      (391.99543598174927, 0.5921052631578948),
                      (440.0, 0.17269736842105263),
@@ -553,7 +556,39 @@ class ParserTests(unittest.TestCase):
                      (130.8127826502993, 0.34539473684210525),
                      (0, 0.4440789473684211),
                      1]]
-        self.assertListEqual(res, expected)
+        self.assertListEqual(round_sequence_r(res), round_sequence_r(expected))
 
-if __name__ == "__main__":
-    unittest.main()
+    def test_mml_details(self):
+        input = 'ml|ol o bc n cb p bc- p cb+ p o5cbf p o5cn60f'
+        expected_mml = "O4L4T120MN ML O4B>CN0C<BP4BBP4CCP4O5C<BFP4O5CN60F"
+        expected_lst = [
+                        # B C → B >C
+                        (1975.533205024496, 0.5),
+                        (2093.004522404789, 0.5),
+                        (0, 0.5),
+                        # C B → C <B
+                        (2093.004522404789, 0.5),
+                        (1975.533205024496, 0.5),
+                        (0, 0.5),
+                        # B C♭(=B) → B‿B
+                        (1975.533205024496, 1.0),
+                        (0, 0.5),
+                        # C B♯(=C) → C‿C
+                        (2093.004522404789, 1.0),
+                        (0, 0.5),
+                        # C B F → C <B F
+                        (2093.004522404789, 0.5),
+                        (1975.533205024496, 0.5),
+                        (1396.9129257320155, 0.5),
+                        (0, 0.5),
+                        # C B† F → C B F (†=with N command)
+                        # because N doesn’t affect octave tracking
+                        (2093.004522404789, 0.5),
+                        (1975.533205024496, 0.5),
+                        (2793.825851464031, 0.5)]
+        res = [0, 0]
+        def _getres(s):
+            res[0] = s
+        res[1] = mml(input, _mmltrk=_getres)
+        self.assertEqual(res[0], expected_mml)
+        self.assertListEqual(round_sequence_r(res[1]), round_sequence_r(expected_lst))
