@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # ~*~ coding: utf-8 ~*~
 
 # Copyright © 2017
@@ -22,21 +21,20 @@
 import os
 import unittest
 
-from .util import round_sequence_r
+from .util import round_sequence_r, TestCase
 
 from mmllib.parser import mml_file
 from mmllib.playlist import convert_to_timedlist
 
-class PlaylistTests(unittest.TestCase):
+class PlaylistTests(TestCase):
     def setUp(self):
         self.datadir = os.path.join(os.path.dirname(__file__), "data")
-        self.examplesdir = os.path.abspath(os.path.join(self.datadir, "..", "..", "examples"))
 
     def test_convert_to_timedlist(self):
-        mmlfile = os.path.join(self.examplesdir, "loreley.mml")
+        mmlfile = os.path.join(self.datadir, "loreley.mml")
         res, errors = convert_to_timedlist(mml_file(mmlfile))
         expected = [(0.39473684210526316,
-                     [(0.0, [(1, 391.99543598174927)]), (0.34538999999999997, [(1, 0)])]),
+                     [(0.0, [(1, 391.99543598174927)]), (0.29604999999999998, [(1, 0)])]),
                     (2.3684210526315792,
                      [(0.0,
                        [(1, 391.99543598174927),
@@ -393,6 +391,3 @@ class PlaylistTests(unittest.TestCase):
                       (1.5296000000000001, [(1, 0), (2, 0), (4, 0)])])]
         self.assertListEqual(round_sequence_r(res), round_sequence_r(expected))
         self.assertEqual(errors, [])
-
-if __name__ == "__main__":
-    unittest.main()
